/*
**  session.h (FrontDoor)
**
**  Copyright 1991 Joaquim H. Homrighausen. All rights reserved.
**
**  PASSWORD.FD format for FrontDoor 2.00+
**
**  Last revision:  91-10-02
**                            
**  -------------------------------------------------------------------------
**  This information is not necessarily final and is subject to change at any
**  given time without further notice
**  -------------------------------------------------------------------------
*/


/*
**  Status values, non-exclusive bit values
**
**  I.e. If the NOFREQS and ACTIVE options were set for an entry in the
**       security list, the status field would contain 0x05.
*/
#define ACTIVE      0x01                  /* Active, as opposed to inactive */
#define DELETED     0x02                           /* Never written to disk */
#define NOFREQS     0x04           /* Don't allow file requests from system */
#define NOMAIL      0x08                    /* Don't allow mail from system */
#define NOEMSI      0x10              /* No outbound EMSI sessions w/system */
#define NOFTSC1     0x20            /* No outbound FTSC-1 sessions w/system */
#define NOZAP       0x40            /* No outbound ZedZap sessions w/system */
#define NOYOOHOO    0x80            /* No outbound YooHoo sessions w/system */

/*
**  Note that any settings in the FDOPT environment variable applies to
**  all sessions (inbound AND outbound). For example, if FDOPT contains
**  "NOEMSI", NO EMSI handshaking will be done, regardless of settings
**  in the security manager
*/

typedef struct
    {
    word    zone,
            net,
            node,
            point;
    char    password[9];                                  /* NUL terminated */
    byte    status;
    }
    _PSW, *PSWPTR;

/* end of file "session.h" */
