/*
**  sreq.h (FrontDoor)
**
**  Structures of file created during an inbound service request
**
**  Copyright 1991 Joaquim H. Homrighausen. All rights reserved
**
**  Last revised: 91-10-02
*/

/*
**  Nodelist capability bit values
*/
#define CMFLAG      0x00000002L                                     /* "CM" */
#define MOFLAG      0x00000004L                                     /* "MO" */
#define HSTFLAG     0x00000008L                                    /* "HST" */
#define H96FLAG     0x00000010L                                    /* "H96" */
#define PEPFLAG     0x00000020L                                    /* "PEP" */
#define MAXFLAG     0x00000040L                                    /* "MAX" */
#define XXFLAG      0x00000080L                                     /* "XX" */
#define XBFLAG      0x00000100L                                     /* "XB" */
#define XRFLAG      0x00000200L                                     /* "XR" */
#define XPFLAG      0x00000400L                                     /* "XP" */
#define XWFLAG      0x00000800L                                     /* "XW" */
#define MNPFLAG     0x00001000L                                    /* "MNP" */
#define V29FLAG     0x00002000L                                    /* "V29" */
#define V32FLAG     0x00004000L                                    /* "V32" */
#define V33FLAG     0x00008000L                                    /* "V33" */
#define V34FLAG     0x00010000L                                    /* "V34" */
#define V42FLAG     0x00020000L                                    /* "V42" */
#define XCFLAG      0x00040000L                                     /* "XC" */
#define XAFLAG      0x00080000L                                     /* "XA" */
#define V42bFLAG    0x00100000L                                   /* "V42B" */
#define V32bFLAG    0x00200000L                                   /* "V32B" */
#define CSPFLAG     0x00400000L                                    /* "CSP" */


/*
**  The resulting file is written as:
**
**  <_InfoRec>                  <See below>
**  <NumValidEntriesInIDList>   <16-bit integer>
**  <_RemoteID * 20>            <See below>
**
**  All char[] fields are Pascal style (ie. the first byte is the length
**  byte and there is no terminating NUL character).
*/
typedef struct
    {
    unsigned int    zone,                                            /* AKA */
                    net,
                    node,
                    point;
    unsigned char   denied;             /* Whether "DENY" is applied to AKA */
    }
    _RemoteID;

typedef struct
    {
    char            name[81],                                /* System name */
                    operator[81],                        /* System operator */
                    location[41],                        /* System location */
                    phone[27],             /* System telephone number (raw) */
                    domain[30];
    unsigned int    baud;                    /* Maximum baud rate of system */
    char            flags[52];             /* Nodelist flags (as presented) */
    unsigned int    zone,    /* Primary AKA, same as first _RemoteID record */
                    net,
                    node,
                    point;
    unsigned long   capabilities;  /* Nodelist flags (as found in Nodelist) */
    char            trx_num[11],                      /* Transaction number */
                    serialnum[32],                         /* Serial number */
                    password[18];                 /* Session level password */
    }
    _InfoRec;

/* end of file "sreq.h" */
